@@ -1,9 +1,10 @@
 # pylint: disable=wrong-import-order
+# pylint: disable=ungrouped-imports
 """
 DBT adapter connection implementation for Exasol.
 """
 import decimal
-import time
+import os
 from contextlib import contextmanager
 from dataclasses import dataclass
 from typing import Any, List, Optional
@@ -12,28 +13,43 @@ import agate
 import dbt.exceptions
 import pyexasol
 from dbt.adapters.base import Credentials  # type: ignore
-from dbt.adapters.exasol.relation import ProtocolVersionType
 from dbt.adapters.sql import SQLConnectionManager  # type: ignore
 from dbt.contracts.connection import AdapterResponse
-from dbt.logger import GLOBAL_LOGGER as logger  # type: ignore
+from dbt.events import AdapterLogger
+from hologram.helpers import StrEnum
 from pyexasol import ExaConnection
 
+ROW_SEPARATOR_DEFAULT = "LF" if os.linesep == "\n" else "CRLF"
+TIMESTAMP_FORMAT_DEFAULT = "YYYY-MM-DDTHH:MI:SS.FF6"
+
+LOGGER = AdapterLogger("exasol")
+
 
 def connect(**kwargs: bool):
     """
-    Global connect method initialising ExasolConnection
+    Global connect method initializing ExasolConnection
     """
     if "autocommit" not in kwargs:
         kwargs["autocommit"] = False
-
     return ExasolConnection(**kwargs)
 
 
+class ProtocolVersionType(StrEnum):
+    """Exasol protocol versions"""
+
+    V1 = "v1"
+    V2 = "v2"
+    V3 = "v3"
+
+
 class ExasolConnection(ExaConnection):
     """
     Override to instantiate ExasolCursor
     """
 
+    row_separator: str = ROW_SEPARATOR_DEFAULT
+    timestamp_format: str = TIMESTAMP_FORMAT_DEFAULT
+
     def cursor(self):
         """Instance of ExasolCursor"""
         return ExasolCursor(self)
@@ -48,6 +64,7 @@ class ExasolAdapterResponse(AdapterResponse):
     execution_time: Optional[float] = None
 
 
+# pylint: disable=too-many-instance-attributes
 @dataclass
 class ExasolCredentials(Credentials):
     """Profile parameters for Exasol in dbt profiles.yml"""
@@ -64,7 +81,8 @@ class ExasolCredentials(Credentials):
     query_timeout: int = pyexasol.constant.DEFAULT_QUERY_TIMEOUT
     compression: bool = False
     encryption: bool = False
-    ## Because of potential interference with dbt, the following statements are not (yet) implemented
+    ## Because of potential interference with dbt,
+    # the following statements are not (yet) implemented
     # fetch_dict: bool
     # fetch_size_bytes: int
     # lower_ident: bool
@@ -74,6 +92,8 @@ class ExasolCredentials(Credentials):
     # udf_output_port: int
     protocol_version: str = "v3"
     retries: int = 1
+    row_separator: str = ROW_SEPARATOR_DEFAULT
+    timestamp_format: str = TIMESTAMP_FORMAT_DEFAULT
 
     _ALIASES = {"dbname": "database", "pass": "password"}
 
@@ -97,6 +117,8 @@ class ExasolCredentials(Credentials):
             "compression",
             "encryption",
             "protocol_version",
+            "row_separator",
+            "timestamp_format",
         )
 
 
@@ -111,9 +133,9 @@ class ExasolConnectionManager(SQLConnectionManager):
             yield
 
         except Exception as yielded_exception:
-            logger.debug(f"Error running SQL: {sql}")
-            logger.debug("Rolling back transaction.")
-            self.release()
+            LOGGER.debug(f"Error running SQL: {sql}")
+            LOGGER.debug("Rolling back transaction.")
+            self.rollback_if_open()
             if isinstance(yielded_exception, dbt.exceptions.RuntimeException):
                 # during a sql query, an internal to dbt exception was raised.
                 # this sounds a lot like a signal handler and probably has
@@ -143,11 +165,12 @@ class ExasolConnectionManager(SQLConnectionManager):
         return dbt.clients.agate_helper.table_from_data_flat(data, column_names)  # type: ignore
 
     @classmethod
+    # pylint: disable=raise-missing-from
     def open(cls, connection):
         if connection.state == "open":
-            logger.debug("Connection is already open, skipping open.")
+            LOGGER.debug("Connection is already open, skipping open.")
             return connection
-        credentials = cls.get_credentials(connection.credentials)
+        credentials = connection.credentials
 
         # Support protocol versions
         try:
@@ -166,7 +189,7 @@ class ExasolConnectionManager(SQLConnectionManager):
             )
 
         def _connect():
-            return connect(
+            conn = connect(
                 dsn=credentials.dsn,
                 user=credentials.user,
                 password=credentials.password,
@@ -178,52 +201,32 @@ class ExasolConnectionManager(SQLConnectionManager):
                 encryption=credentials.encryption,
                 protocol_version=protocol_version,
             )
+            # exasol adapter specific attributes that are unknown to pyexasol
+            # those can be added to ExasolConnection as members
+            conn.row_separator = credentials.row_separator
+            conn.timestamp_format = credentials.timestamp_format
+            conn.execute(
+                f"alter session set NLS_TIMESTAMP_FORMAT='{conn.timestamp_format}'"
+            )
 
-        retryable_exceptions = [pyexasol.ExaError]
+            return conn
+
+        repeatable_exceptions = [pyexasol.ExaError]
 
         return cls.retry_connection(
             connection,
             connect=_connect,
-            logger=logger,
+            logger=LOGGER,
             retry_limit=credentials.retries,
-            retryable_exceptions=retryable_exceptions,
+            retryable_exceptions=repeatable_exceptions,
         )
 
-    def commit(self):
-        connection = self.get_thread_connection()
-        if dbt.flags.STRICT_MODE:  # type: ignore
-            assert isinstance(connection, ExaConnection)
-
-        logger.debug(f"On {connection.name}: COMMIT")
-        self.add_commit_query()
-
-        connection.transaction_open = False
-
-        return connection
-
-    def begin(self):
-        connection = self.get_thread_connection()
-
-        if dbt.flags.STRICT_MODE:
-            assert isinstance(connection, ExaConnection)
-
-        if connection.transaction_open is True:
-            raise dbt.exceptions.InternalException(
-                f"Tried to begin a new transaction on connection {connection.name}, "
-                "but it already had one open!"
-            )
-
-        connection.transaction_open = True
-        return connection
+    def add_begin_query(self):
+        return
 
     def cancel(self, connection):
         connection.abort_query()  # type: ignore
 
-    @classmethod
-    def get_status(cls, cursor):
-        """Override status"""
-        return "OK"
-
     @classmethod
     def get_response(cls, cursor) -> ExasolAdapterResponse:
         return ExasolAdapterResponse(
@@ -232,42 +235,8 @@ class ExasolConnectionManager(SQLConnectionManager):
             execution_time=cursor.execution_time,
         )
 
-    @classmethod
-    def get_credentials(cls, credentials):
-        """override get_credentials"""
-        return credentials
 
-    def add_query(self, sql, auto_begin=True, bindings=None, abridge_sql_log=False):
-        connection = self.get_thread_connection()
-        if auto_begin and connection.transaction_open is False:
-            self.begin()
-        logger.debug(sql)
-        logger.debug(f'Using {self.TYPE} connection "{connection.name}".')
-
-        if sql.startswith("0CSV|"):
-            connection.handle.cursor().import_from_file(bindings, sql.split("|", 1)[1])  # type: ignore
-
-            return connection
-
-        with self.exception_handler(sql):
-            if abridge_sql_log:
-                logger.debug("On {}: {}....".format(connection.name, sql[0:512]))
-            else:
-                logger.debug("On {}: {}".format(connection.name, sql))
-            pre = time.time()
-
-            cursor = connection.handle.cursor().execute(sql)  # type: ignore
-
-            logger.debug(
-                "SQL status: {} in {:.2f} seconds".format(
-                    self.get_status(cursor), (time.time() - pre)
-                )
-            )
-
-            return connection, cursor
-
-
-class ExasolCursor(object):
+class ExasolCursor:
     """Exasol dbt-adapter cursor implementation"""
 
     array_size = 1
@@ -281,54 +250,58 @@ class ExasolCursor(object):
         self.connection.import_from_file(
             agate_table.original_abspath,
             (table.split(".")[0], table.split(".")[1]),
-            import_params={"skip": 1},
+            import_params={"skip": 1, "row_separator": self.connection.row_separator},
         )
-
-    def execute(self, query):
-        """executing query"""
-        self.stmt = self.connection.execute(query)
         return self
 
-    def executemany(self, query):
-        """execute many not implemented yet"""
-        raise RuntimeError
+    def execute(self, query, bindings: Optional[Any] = None):
+        """executing query"""
+        if query.startswith("0CSV|"):
+            self.import_from_file(bindings, query.split("|", 1)[1])  # type: ignore
+        else:
+            self.stmt = self.connection.execute(query)
+        return self
 
     def fetchone(self):
+        """fetch single row"""
+        if self.stmt is None:
+            raise RuntimeError("Cannot fetch on unset statement")
         return self.stmt.fetchone()
 
     def fetchmany(self, size=None):
+        """fetch single row"""
         if size is None:
             size = self.array_size
 
+        if self.stmt is None:
+            raise RuntimeError("Cannot fetch on unset statement")
         return self.stmt.fetchmany(size)
 
     def fetchall(self):
+        """fetch single row"""
+        if self.stmt is None:
+            raise RuntimeError("Cannot fetch on unset statement")
         return self.stmt.fetchall()
 
-    def nextset(self):
-        raise RuntimeError
-
-    def setinputsizes(self):
-        pass
-
-    def setoutputsize(self):
-        pass
-
     @property
     def description(self):
+        """columns in cursor"""
         cols = []
+        if self.stmt is None:
+            return cols
+
         if "resultSet" != self.stmt.result_type:
             return None
 
-        for k, v in self.stmt.columns().items():
+        for k, value_set in self.stmt.columns().items():
             cols.append(
                 (
                     k,
-                    v.get("type", None),
-                    v.get("size", None),
-                    v.get("size", None),
-                    v.get("precision", None),
-                    v.get("scale", None),
+                    value_set.get("type", None),
+                    value_set.get("size", None),
+                    value_set.get("size", None),
+                    value_set.get("precision", None),
+                    value_set.get("scale", None),
                     True,
                 )
             )
@@ -337,11 +310,19 @@ class ExasolCursor(object):
 
     @property
     def rowcount(self):
-        return self.stmt.rowcount()
+        """number of rows in result set"""
+        if self.stmt is not None:
+            return self.stmt.rowcount()
+        return 0
 
     @property
     def execution_time(self):
-        return self.stmt.execution_time
+        """elapsed time for query"""
+        if self.stmt is not None:
+            return self.stmt.execution_time
+        return 0
 
     def close(self):
-        self.stmt.close()
+        """closing the cursor / statement"""
+        if self.stmt is not None:
+            self.stmt.close()
