@@ -178,3 +178,9 @@ AS
 COMMENT IS '{{ model.description }}'
 {%- endif %}
 {% endmacro %}
+
+{% macro exasol__alter_column_type(relation, column_name, new_column_type) -%}
+  {% call statement('alter_column_type') %}
+    alter table {{ relation }} modify column {{ adapter.quote(column_name) }} {{ new_column_type }};
+  {% endcall %}
+{% endmacro %}
\ No newline at end of file
